/**-----------------------------------------------------------------------------------------
* Copyright © 2024 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { AfterContentChecked, ElementRef, Renderer2, OnDestroy, NgZone } from '@angular/core';
import { SelectionService } from './selection.service';
import { CellSelectionAggregateService } from '../aggregates/selection-aggregate.service';
import { CellSelectionService } from './cell-selection.service';
import * as i0 from "@angular/core";
/**
 * Represents the row-selection checkbox of the Grid. The directive expects the
 * index of the current row as an input parameter. Inside the [`CellTemplateDirective`](slug:api_grid_celltemplatedirective), apply the
 * `kendoGridSelectionCheckbox` to an `<input type="checkbox"/>` element. When the user clicks the checkbox that is associated
 * with the directive, a [selectionChange](slug:api_grid_gridcomponent#toc-selectionChange)
 * event is triggered.
 *
 * @example
 * ```html
 * <kendo-grid ... >
 *   <kendo-grid-column>
 *     <ng-template kendoGridCellTemplate let-rowIndex="rowIndex">
 *       <input ... [kendoGridSelectionCheckbox]="rowIndex"/>
 *     </ng-template>
 *   </kendo-grid-column>
 * </kendo-grid>
 * ```
 */
export declare class SelectionCheckboxDirective implements AfterContentChecked, OnDestroy {
    private selectionService;
    private cellSelectionService;
    private aggregateService;
    private el;
    private renderer;
    private ngZone;
    /**
     * The current index of the `dataItem` that will be selected.
     */
    itemIndex: number;
    type: string;
    private destroyClick;
    private destroyKeyDown;
    ngAfterContentChecked(): void;
    constructor(selectionService: SelectionService, cellSelectionService: CellSelectionService, aggregateService: CellSelectionAggregateService, el: ElementRef, renderer: Renderer2, ngZone: NgZone);
    ngOnDestroy(): void;
    private onClick;
    private onKeyDown;
    private setCheckedState;
    static ɵfac: i0.ɵɵFactoryDeclaration<SelectionCheckboxDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<SelectionCheckboxDirective, "[kendoGridSelectionCheckbox]", never, { "itemIndex": "kendoGridSelectionCheckbox"; }, {}, never, never, true, never>;
}
